package org.ets.ibt.external.services.ibis;

import java.io.Serializable;
import java.net.URL;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;
import org.ets.ibt.delivery.server.config.ConfigParamCache;
import org.ets.ibt.delivery.server.utility.ServerProperties;
import org.ets.ibt.external.clients.ibis.ACDDataServiceBindingStub;
import org.ets.ibt.external.clients.ibis.ACDDataServiceServiceLocator;
import org.ets.ibt2.common.enums.OAuthEnums;
import org.ets.ibt2.common.util.oauth.OauthServiceUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class ACDDataServiceReposter implements Serializable {

   private static final Logger Log = LoggerFactory.getLogger(ACDDataServiceReposter.class);
   private static final long serialVersionUID = -4974638781675436992L;


   public static void postACD(String pkgId, String adminCode, String acdCode, byte[] acdData) throws Exception {
      List urlInfoList = ServerProperties.getWebServiceReposterURLInfo();
      if(urlInfoList.isEmpty()) {
         Log.info("postACD(): repost URL is empty! No ACD is reposted");
      } else {
         boolean repostOAuthFlag = ServerProperties.isProducerOAuthRepostFlag();
         Log.info("postACD(): starting to repost ACD. Destination size = {}, repostOAuthFlag = {}", Integer.valueOf(urlInfoList.size()), Boolean.valueOf(repostOAuthFlag));
         Iterator var6 = urlInfoList.iterator();

         while(var6.hasNext()) {
            List urlInfo = (List)var6.next();
            String url = (String)urlInfo.get(0);
            String token;
            if(!repostOAuthFlag) {
               token = (String)urlInfo.get(1);
               String pwd = (String)urlInfo.get(2);
               postACD(pkgId, adminCode, acdCode, acdData, url, token, pwd);
            } else {
               Log.info("ACDDataService: Generating IDAAS TOKEN");
               OAuthEnums.BEARER.getValue();
               token = OauthServiceUtils.getInstance().getCachedOAuthTokenByUrl(OAuthEnums.UNIFY_INTERNAL_REPOST_OAUTH_CACHE.getValue(), ServerProperties.getOauthTokenURL(), ConfigParamCache.getInstance().getAwsSecretsManagerParamValue(OAuthEnums.UNIFY_INTERNAL_CLIENT_ID.getValue()), ConfigParamCache.getInstance().getAwsSecretsManagerParamValue(OAuthEnums.UNIFY_INTERNAL_CLIENT_SECRET.getValue()), (String)urlInfo.get(3));
               postACD(pkgId, adminCode, acdCode, acdData, url, token);
            }
         }

      }
   }

   public static void postACD(String pkgId, String adminCode, String acdCode, byte[] acdData, String url, String userId, String pwd) {
      new Thread;
      acdCode.<init>(acdData);
      pkgId.start();
   }

   public static void postACD(String pkgId, String adminCode, String acdCode, byte[] acdData, String url, String oAuthToken) {
      new Thread;
      acdCode.<init>(acdData);
      pkgId.start();
   }

   public static void main(String[] args) throws Exception {
      String s = "Test ACD";
      String url = "http://localhost:8001/internal/services/ACDDataService";
      OAuthEnums.BEARER.getValue();
      String oAuthToken = OauthServiceUtils.getInstance().getCachedOAuthTokenByUrl("unify.internal.oauth.cache", "https://idcs-89dbabaeaec14e77bc1d53cb19f1932d.identity.oraclecloud.com/oauth2/v1/token", "2573fbdf01014566929ddddb5c455104", "68652a8d-8241-4c7f-bbcb-1391756caa1e", "https://ibt2-cloud-sb.ets.org/unify/services/");
      postACD("GRIGENAUO00045000PKG001", "20190111D", "123", s.getBytes(), url, oAuthToken);
   }

   // $FF: synthetic method
   private static void lambda$postACD$1(String url, String oAuthToken, String adminCode, String pkgId, String acdCode, byte[] acdData) {
      try {
         Log.info("postACD(): ACD repost to {}, OAuth Authentication ", url);
         ACDDataServiceServiceLocator e = new ACDDataServiceServiceLocator();
         e.setACDDataServicePortEndpointAddress(url);
         org.ets.ibt.external.clients.ibis.ACDDataService service = e.getACDDataServicePort(new URL(url));
         ACDDataServiceBindingStub stub = (ACDDataServiceBindingStub)e.getPort(service.getClass());
         Hashtable headers = new Hashtable();
         headers.put("Authorization", oAuthToken);
         stub._setProperty("HTTP-Request-Headers", headers);
         String returnCode = stub.setACDDataCompressed(adminCode, pkgId, acdCode, acdData);
         Log.info("postACD(): status = {}", returnCode);
      } catch (Exception var14) {
         Log.error("postACD()", var14);
      } finally {
         Log.info("postACD(): posting ACD is completed");
      }

   }

   // $FF: synthetic method
   private static void lambda$postACD$0(String url, String userId, String pwd, String adminCode, String pkgId, String acdCode, byte[] acdData) {
      try {
         Log.info("postACD(): ACD repost to {}, LDAP Authentication ", url);
         ACDDataServiceServiceLocator e = new ACDDataServiceServiceLocator();
         e.setACDDataServicePortEndpointAddress(url);
         org.ets.ibt.external.clients.ibis.ACDDataService service = e.getACDDataServicePort(new URL(url));
         ACDDataServiceBindingStub stub = (ACDDataServiceBindingStub)e.getPort(service.getClass());
         stub.setUsername(userId);
         stub.setPassword(pwd);
         String returnCode = stub.setACDDataCompressed(adminCode, pkgId, acdCode, acdData);
         Log.info("postACD(): status = {}", returnCode);
      } catch (Exception var14) {
         Log.error("postACD()", var14);
      } finally {
         Log.info("postACD(): posting ACD is completed");
      }

   }

}
